@@ -81,8 +81,7 @@ class FastTracker:
         :param tenant_code:
         :return:
         """
-        if tenant_code:
-            config.custom_tenant_code = tenant_code
+        return config.set_tenant_code(tenant_code)
 
     @property
     def user_code(self):
@@ -99,8 +98,7 @@ class FastTracker:
         :param user_code:
         :return:
         """
-        if user_code:
-            config.custom_user_code = user_code
+        return config.set_user_code(user_code)
 
     @property
     def service_name(self):
@@ -119,6 +117,23 @@ class FastTracker:
         """
         config.set_service_name(service_name)
 
+    @property
+    def service_version(self):
+        """
+        获取 service_version 值
+        :return:
+        """
+        return config.custom_service_version if config.custom_service_version else config.service_version
+
+    @service_version.setter
+    def service_version(self, service_version: str = ""):
+        """
+        设置 service_version 值
+        :param service_version:
+        :return:
+        """
+        config.set_service_version(service_version)
+
     @property
     def socket_path(self):
         """
@@ -306,7 +321,7 @@ class FastTracker:
             context = get_context()
             if not context:
                 raise RuntimeError("探针未启动")
-            with context.new_local_span(op="Logging") as span:
+            with context.new_local_span(op=err_type) as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
                 span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(msg, err_type="DEBUG"))]))
